%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CALCIDEAL.M: Compute ideal slant for each newspaper.
%
% INPUTS
%   data        nd x 4                  data array: columns are [dindex UTIL REP HH]
%   b           3 x 1                   parameter vector: rows are rep_slant, rep, rep2
%   sd          scalar                  standard deviation of slant (for perturbation)
%
% OUTPUTS
%   ideal       (nd*ndraws+1) x 4       ideal slant at estimated and simulated parameter values:
%                                       cols are draw, dindex, ideal, idealshare
%   param       (nd+1) x 4              parameter draws at each monte carlo simulation:
%                                       cols are index of draw, alpha, beta, gamma
%
% note: draw indexed zero is the actual esimated parameter values
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ideal pctloss param] = calcideal(data,b,sd)

global SLANT REP LOGIT HH ALPHA BETA GAMMA

% set seed
randn('state',04271975)

% store vector of dindices
dind = unique(data(:,1));
nd = length(dind);

% create temporary data arrays
ideal = zeros(nd,length(b)+1);
fval = zeros(nd,length(b)+1);
pctloss = zeros(nd,length(b)+1);

% define perturbation for numerical derivatives
% pert = max{10^-6 , x*10^-6} following
% Judd, Kenneth L. Numerical Methods in Economics. p. 36.
pert = max(10^-6,b*10^-6);

% create matrix of parameters at observed and perturbed values
% (perturbations are for numerical derivatives)
param = [b (repmat(b,1,length(b)) + diag(pert))];

% compute ideal point at each draw (beginning w/ true value)
for d = 1:length(b)+1

    ALPHA = param(1,d);
    BETA = param(2,d);
    GAMMA = param(3,d);
    
    for i=1:nd

        SLANT = data(data(:,1)==dind(i),2);
        LOGIT = data(data(:,1)==dind(i),3);
        REP = data(data(:,1)==dind(i),4);
        HH = data(data(:,1)==dind(i),5);

	lb = min(ALPHA,ALPHA+BETA);
        ub = max(ALPHA,ALPHA+BETA);
        
        % find ideal point by minimizing negshare
        [ideal(i,d),fval(i,d)]=fminbnd(@negshare,lb,ub);

        % calculate avg share at ideal +/- one std deviation
        ishare = -fval(i,d);
        ishare_1sd = -.5*(negshare(ideal(i,d)+sd)+negshare(ideal(i,d)-sd));

        % calculate percent loss
        pctloss(i,d)=(ishare_1sd-ishare)/ishare;

    end
end

% create output arrays
ideal = [dind , ideal(:,1), (repmat(ideal(:,1),1,length(b))-ideal(:,2:length(b)+1))./repmat(pert',nd,1)];
pctloss = [dind , pctloss(:,1), (repmat(pctloss(:,1),1,length(b))-pctloss(:,2:length(b)+1))./repmat(pert',nd,1)];

end

% negshare
function ns=negshare(y)
    global SLANT REP LOGIT HH ALPHA BETA GAMMA
     n = length(REP);
     
     % compute new value of LOGIT when we move slant from SLANT-->y
     uu = LOGIT + GAMMA*((SLANT - (ALPHA + BETA*REP)).^2 - (repmat(y,n,1) - (ALPHA + BETA*REP)).^2);
     
     ss = exp(uu)./(1+exp(uu));
     ns = -sum(ss.*HH)/sum(HH);
end





