**********************************************************
*
* BIASMEAS_BUILD.DO: Combine congressional record data
*	with word counts to develop slant measures
*	for sample of newspapers.
*
*
**********************************************************
local datadir "..\external"
local subsetdir "..\external\subset"
local outputdir "..\output"

local newsinfo "..\temp\NewspaperInfo.dta"
local speakerinfo "..\temp\Speakers.dta"

local subsets "all sm"
local cong "109"

* output files
local output "`outputdir'\BiasMeasures.dta"
local outputpeople "`outputdir'\BiasMeasures_people.dta"

tempfile temp
tempfile temp_subset
tempfile divs

**********************************************************
* PRELIMINARIES
**********************************************************
clear
set mem 900m
set matsize 5000
set maxvar 32000
set more off

cap log close
cap log using "..\output\biasmeasures_build.log", replace text

* input files
local news "`outputdir'\\2005_NewsCounts.dta"


***********************************
***** BEGIN LOOP OVER SUBSETS *****
foreach SUB in `subsets' {

* Run extra depvars for all subset only
if "`SUB'" == "all" {
       local depvars "rep ada cs1"
}
else if "`SUB'" != "all" {
       local depvars "rep"
}

************************************************************
* SAVE SUBSET TEMP FILE AND WORDLIST
************************************************************
use "`subsetdir'\subset`SUB'_2005.dta", clear
cap gen group = 1
sort phrase
sort phrase
merge phrase using "`datadir'\\2005_Wordlist.dta"
keep if _merge==3
keep phrase phrase_stub group
sort phrase
save "`temp_subset'", replace

vallist group, local(groups)
foreach G in `groups' {
	vallist phrase_stub if group==`G', local(wordlist`G')
}

*****************************************************************************
* GENERATE SEARCHTERM COEFFICIENTS FROM BYPERSON CONG RECORD DATA
*****************************************************************************
use speaker_id phrase count using "`datadir'\\2005_ByPerson.dta", clear
mmerge speaker_id using "..\temp\Speakers.dta", type(n:1) unmatched(master) ukeep(repshare_109 real_ada cs1)
drop _merge

sort phrase
if length("`groups'") > 1 {
joinby phrase using "`temp_subset'"
}
else {
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge
}

**** Original Code
sort phrase
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge

compress 

* create dep vars
gen rep = repshare_`cong'
ren real_ada ada

* calculate shares
egen totcount = sum(count), by(speaker_id)
drop if totcount==0
egen totcount_grp = sum(count), by(speaker_id group)
gen scount = count/totcount
gen scount_grp = count/totcount_grp
drop totcount_grp


compress

* 1 by 1 reverse regressions (parametric loss function approach)
tempname coeffs
postfile `coeffs' str30 phrase_stub str10 depvar float group alpha_ beta_ se_ using "`subsetdir'\coefficients`SUB'_2005.dta", replace
foreach DEP in `depvars' {
	gen numeratortemp = .
	gen denominatortemp = .
	foreach G in `groups' {
		foreach WORD in `wordlist`G'' {
			disp "`WORD'"
			reg scount_grp `DEP' if phrase_stub=="`WORD'"
			post `coeffs' ("`WORD'") ("`DEP'") (`G') (_b[_cons]) (_b[`DEP']) (_se[`DEP'])

			* generate predicted values for congresspeople
			replace numeratortemp = _b[`DEP'] * (scount_grp - _b[_cons]) if phrase_stub=="`WORD'"
			replace denominatortemp = _b[`DEP']^2 if phrase_stub=="`WORD'"
		}
	}

	egen numerator = sum(numeratortemp), by(speaker_id)
	egen denominator = sum(denominatortemp), by(speaker_id)
	gen pred_`DEP'`SUB'_2005 = (numerator/denominator)
	drop numerator* denominator*

}
postclose `coeffs'

keep speaker_id pred_* totcount*
duplicates drop
renvars totcount*, postfix(`SUB'_2005)
sort speaker_id
save "`subsetdir'\people`SUB'_2005.dta", replace

* reshape coefficient file
use "`subsetdir'\coefficients`SUB'_2005.dta", clear

if length("`groups'") > 1 {
reshape wide alpha beta se, i(phrase_stub group) j(depvar) string
}
else {
reshape wide alpha beta se, i(phrase_stub) j(depvar) string
}

renvars alpha* beta* se*, postfix(`SUB'_2005)
sort phrase_stub
save "`subsetdir'\coefficients`SUB'_2005.dta", replace

**********************************************************
* APPLY TO ANALYZE NEWSPAPER DATA
**********************************************************
use "`news'", clear

sort phrase

if length("`groups'") > 1 {
joinby phrase using "`temp_subset'"
}
else {
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge
}

*** Original Code
sort phrase
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge

sort phrase_stub
merge phrase_stub using "`subsetdir'\coefficients`SUB'_2005.dta"
tab _merge
drop _merge

* calculate shares
egen totcount = sum(hitcount), by(dindex)
drop if totcount==0
egen totcount_grp = sum(hitcount), by(dindex group)
gen scount = hitcount/totcount
gen scount_grp = hitcount/totcount_grp
drop totcount_grp


compress

* 1 by 1 reverse regressions (parametric loss function approach)
foreach DEP in `depvars' {
	gen num_`DEP' = beta_`DEP'`SUB'_2005 * (scount_grp - alpha_`DEP'`SUB'_2005)
	egen numsum_`DEP' = sum(num_`DEP'), by(dindex)
	gen den_`DEP' = beta_`DEP'`SUB'_2005^2
	egen densum_`DEP' = sum(den_`DEP'), by(dindex)
	gen pred_`DEP'`SUB'_2005 = (numsum_`DEP'/densum_`DEP')
}

renvars totcount* num_* numsum_* den_* densum_*, postfix(`SUB'_2005)
renvars hitcount scount scount_grp, postfix(2005)

sort dindex phrase
save "`subsetdir'\detail`SUB'_2005.dta", replace

keep dindex pred_* totcount*
duplicates drop

sort dindex
save "`subsetdir'\output`SUB'_2005.dta", replace

**********************************************************
* WASHINGTON BUREAU MEASURE
**********************************************************
if strmatch("`SUB'", "all")&2005==2005{
use "..\external\2005_NewsCounts_wash.dta", clear

sort phrase

if length("`groups'") > 1 {
joinby phrase using "`temp_subset'"
}
else {
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge
}

*** Original Code
sort phrase
merge phrase using "`temp_subset'"
tab _merge
keep if _merge==3
drop _merge

sort phrase_stub
merge phrase_stub using "`subsetdir'\coefficients`SUB'_2005.dta"
tab _merge
drop _merge

* calculate shares
egen totcount = sum(hitcount), by(dindex)
drop if totcount==0
egen totcount_grp = sum(hitcount), by(dindex group)
gen scount = hitcount/totcount
gen scount_grp = hitcount/totcount_grp
drop totcount_grp


compress

* 1 by 1 reverse regressions (parametric loss function approach)
foreach DEP in rep {
	gen num_`DEP' = beta_`DEP'`SUB'_2005 * (scount_grp - alpha_`DEP'`SUB'_2005)
	egen numsum_`DEP' = sum(num_`DEP'), by(dindex)
	gen den_`DEP' = beta_`DEP'`SUB'_2005^2
	egen densum_`DEP' = sum(den_`DEP'), by(dindex)
	gen pred_wb`SUB'_2005 = (numsum_`DEP'/densum_`DEP')
}

renvars totcount* num_* numsum_* den_* densum_*, postfix(`SUB'_2005)
renvars hitcount scount scount_grp, postfix(2005)

sort dindex phrase
save "`subsetdir'\detailwb`SUB'_2005.dta", replace

keep dindex pred_* totcount*
duplicates drop

sort dindex
save "`subsetdir'\outputwb`SUB'_2005.dta", replace
}

}


**********************************************************
* COMBINE FILES
**********************************************************

* output file
use "`newsinfo'", clear
foreach SUB in `subsets' {
	sort dindex
	merge dindex using "`subsetdir'\output`SUB'_2005.dta"
	tab _merge
	drop _merge
}

renvars pred_* totcount*, subst(all)
egen nonmiss = rownonmiss(pred_*)
drop if nonmiss==0
drop nonmiss
egen circrank = rank(-dailycirc)
sort dindex
compress

** Drop AP Wire Stories **
drop if dindex == 9999

** Merge in Wash Bureau scores
sort dindex
merge dindex using "`subsetdir'\outputwball_2005.dta", keep(pred_wball_2005)
tab _m
drop if _m == 2
drop _m
sort dindex

save "`output'", replace

* people file
use "`speakerinfo'", clear
compress
foreach SUB in `subsets' {
	sort speaker_id
	merge speaker_id using "`subsetdir'\people`SUB'_2005.dta"
	tab _merge
	drop _merge
}

egen nonmiss = rownonmiss(pred_*)
drop if nonmiss==0
drop nonmiss
renvars totcount*, subst(all)
gen congress = floor(speaker_id / 1000)
placevar speaker_id congress
save "`outputpeople'", replace

* coefficient file
use  "`datadir'\\2005_Wordlist.dta", clear
compress
keep phrase phrase_stub originalphrase stemcount originalcount chi2 naiverat words dcount rcount
foreach SUB in `subsets' {
	sort phrase_stub
	merge phrase_stub using "`subsetdir'\coefficients`SUB'_2005.dta"
	drop _merge
	compress
}
cap renvars beta_all se_all t_all, postsub(_all)
placevar phrase originalphrase words alpha* beta* se* chi2 naiverat
duplicates drop
sort phrase
save "`outputdir'\BiasMeasures_coeffs_2005.dta", replace


* erase extra files
foreach SUB in `subsets' {
	erase "`subsetdir'\output`SUB'_2005.dta"
	erase "`subsetdir'\people`SUB'_2005.dta"
	erase "`subsetdir'\coefficients`SUB'_2005.dta"
}


log close
