 **********************************************************
 *
 * COSTREV_BUILD.DO: Estimates zipcode-level profitability weights.
 *
 *
 **********************************************************

**********************************************************
* FILENAMES
**********************************************************
local demand "..\output\demand.dta"
local demos "..\external\demos.dta"
local dailies "..\external\dailies2001_clean.dta"
local states "..\external\state.dta"

tempfile np_vars costrev temp

local outfile "..\output\costrev_byzipcode.dta"

**********************************************************
* PRELIMINARIES
**********************************************************
cap log close
clear
set mem 700m
set matsize 500
set maxvar 20000
set more off

**********************************************************
* INPUT VALUES
**********************************************************
* Average newsprint (metric tons) per page from Newsprint.xls
* (avg. estimated from top 15 US dailies)
local NPPERPAGE = 5.525E-06

* Price per metric ton of newsprint from Newsprint.xls
local NPPRICE = 650

* Average number of ad column-inches per page and issue from adspace.xls
local ADINCHESPERPAGE = 27.39
local ADINCHESPERISSUE = 2455

* Estimate ad revenue per inches directly from adspace.xls
local ADREVPERISSUE = 2

* A rough estimate of the share of paper costs in total marginal costs
* (the remainder = ink, printing, distribution)
local PAPERCOSTSHARE = .75

**********************************************************
* LOAD MEAN DEMOS
**********************************************************
use ..\external\means.dta, clear
foreach V of varlist * {
	sum `V'
	scalar `V' = r(mean)
}

***************************************************************
* COMPUTE NEWSPAPER-LEVEL VALUES
***************************************************************
use "`dailies'", clear
gen paper_costperissue = `NPPERPAGE' * `NPPRICE' * pgsdaily 
gen costperissue = paper_costperissue/`PAPERCOSTSHARE'

gen adrevperissue = `ADREVPERISSUE'
gen adrevperissue_alt1 = `ADINCHESPERPAGE' * pgsdaily * (dailyadrate/dailycirc)
gen adrevperissue_alt2 = `ADINCHESPERISSUE' * (dailyadrate/dailycirc)

gen profitperissue = pricedaily+adrevperissue-costperissue
gen profitpersubscriberyear = profitperissue * 52 * 5
gen profitperyear = profitpersubscriberyear * dailycirc
gen adrevperyear = adrevperissue * 52 * 5 * dailycirc

keep dindex papername paper_costperissue-adrevperyear dailycirc pricedaily dailyadrate pgsdaily
placevar dindex papername paper_costperissue-adrevperyear dailycirc pricedaily dailyadrate pgsdaily

sort dindex
save `costrev', replace

**********************************************************
* MERGE DEMOGRAPHIC DATA INTO NEWSPAPER DATA
**********************************************************
use "`dailies'"
sort dindex
merge dindex using "`demos'"

drop _merge
sort state
merge state using "`states'"
keep dindex div dailyadrate dailycirc pgsdaily employees pop00 numhh00 pctwhite00 pctblack00 density00 pcths00 pctcol00 incpc00 timeofday

gen linc98 = log(incpc00)
gen lpop00 = log(pop00)
gen lhh00 = log(numhh00)
gen lcirc = log(dailycirc)
gen ldensity = log(density00)
gen ladrateper = log(dailyadrate/dailycirc)
gen lpages = log(pgsdaily)
gen lemployees = log(employees)
gen evening = timeofday=="e"
tab div, gen(zdiv)

* Run the regression
reg ladrateper pctwhite00 ldensity pctcol00 pcths00 linc98 lpages lemployees evening zdiv2-zdiv9
estimates store regression

* create newspaper-level predicted values
* (first eliminate missing values)
foreach V of varlist pctwhite00 ldensity pctcol00 pcths00 linc98 lpages lemployees evening zdiv2-zdiv9 {
	egen temp = mean(`V')
	replace `V'=temp if `V'==.
	drop temp
}
predict np_ladrateper_hat
save "`temp'", replace

keep dindex evening zdiv* dailyadrate pgsdaily employees
drop if dindex == .
sort dindex
save "`np_vars'", replace

use "`temp'"
keep dindex np_ladrateper_hat
sort dindex
save "`temp'", replace

**********************************************************
* APPLY THE REGRESSION COEFFS TO THE MASTER DATASET OF ZIPS
**********************************************************
use "`demand'"
sort dindex 

* Rename vars to match coeffs (they will be renamed)
gen linc98 = log(zip_pcinc00)
gen lpop00 = log(zip_pop00)
gen ldensity = log(zip_density00)

* merge in missing NP vars
sort dindex
merge dindex using "`np_vars'"
drop if _merge == 2
drop _merge
gen lpages = log(pgsdaily)
gen lemployees = log(employees)

renvars zip_pctwhite00 zip_pcths00 zip_pctcol00, predrop(4)

* eliminate missing values
foreach V of varlist pctwhite00 ldensity pctcol00 pcths00 linc98 lpages lemployees evening {
	replace `V'=`V'_mean if `V'==.
}

* create predicted values
estimates restore regression
predict ladrateper_hat
gen adrateper_hat = exp(ladrateper_hat)

* merge in newspaper-level predicted values
sort dindex
merge dindex using "`temp'"
drop if _merge==2
drop _merge

gen np_adrateper_hat = exp(np_ladrateper_hat)
gen adratefactor = adrateper_hat/np_adrateper_hat

* Re-rename variables
ren pctwhite00 zip_pctwhite00
ren pcths00 zip_pcths00
ren pctcol00 zip_pctcol00

**********************************************************
* MERGE IN OTHER COST/REVENUE VARS AND CLEAN UP
**********************************************************
sort dindex
merge dindex using `costrev'
drop if _m==2
drop _m

* eliminate missing values
foreach V of varlist costperissue pricedaily {
	replace `V'=`V'_mean if `V'==.
}

replace adrevperissue = adrevperissue * adratefactor
replace profitperissue = adrevperissue + pricedaily - costperissue
replace profitpersubscriberyear = profitperissue * 52 * 5

keep dindex zipcode adratefactor adrevperissue costperissue pricedaily profitperissue profitpersubscriberyear

compress
sort dindex zipcode
save "`outfile'", replace

